@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# $Id: attila.sh,v 1.15 2003/04/04 09:22:40 jpc Exp $
+# $Id: attila.sh,v 1.21 2004/09/06 16:15:31 jpc Exp $
 #                                                                        
 # /------------------------------------------------------------------\
 # |                                                                  |
@@ -13,7 +13,29 @@
 # |  sh script :         "./attila"                                  |
 # | **************************************************************** |
 # |  U p d a t e s                                                   |
-# |                                                                  |
+# | $Log: attila.sh,v $
+# | Revision 1.21  2004/09/06 16:15:31  jpc
+# | Added support for Darwin (MacOS X).
+# | Added "--devel" argument.
+# |
+# | Revision 1.20  2004/08/31 08:44:45  jpc
+# | Be less strict in the OS guessing : Fedora Core can change the kernel revision
+# | number...
+# |
+# | Revision 1.19  2004/07/29 07:50:31  alliance
+# | Adding the dynamic link flag for Alliance libraries when installing for
+# | ASIM, since this is required in any case for this type of install
+# |
+# | Revision 1.18  2004/07/24 22:40:33  jpc
+# | La nouvelle config a trois architectures : Linux.FC2, Linux.RH71 et Solaris.
+# |
+# | Revision 1.17  2003/10/29 16:08:54  xtof
+# | changing target machine for installations
+# |
+# | Revision 1.16  2003/10/03 11:36:00  fred
+# | Adding fa: in front of the ATTILA_CVS_ROOT, in order to be able to
+# | retrieve Alliance form machines that do not mount the usual disks.
+# |                                                                 |
 # \------------------------------------------------------------------/
 #
 
@@ -34,8 +56,8 @@
  {
    echo ""
    echo ""
-   echo "Usage : attila [-h] [-L] [-U] [-F] [-A] [-S]                     \\"
-   echo "               [--help] [--local] [--user] [--full] [--asim] [--ssh] \\"
+   echo "Usage : attila [-h] [-L] [-U] [-F] [-A] [-S] [-d]                \\"
+   echo "               [--help] [--local] [--user] [--full] [--asim] [--ssh] [--devel]\\"
    echo "               [--prefix=<INSTALL_DIR>] [--builddir=<BUILD_DIR>] \\"
    echo "               <--tool=<name1> [--tool=<name2> [...]]            \\"
    echo "               [-c- <configure_arg> [...]]                       \\"
@@ -56,6 +78,8 @@
    echo "         Compile/install the requested tool(s) for all"
    echo "         avalaibles architectures. Currently only Linux and Solaris"
    echo "         are supported."
+   echo "     o [-d|--devel]  :"
+   echo "         Uses user's local library first (development version)."
    echo "     o [-A|--asim]  :"
    echo "         Install the tool(s) in the ASIM shared direc-"
    echo "         tory (aka \"\$ALLIANCE_TOP\"), this must be used to upgrade"
@@ -170,9 +194,11 @@
  guess_os ()
  {
    case "`uname -sr`" in
-     Linux*)    echo "Linux";;
-     SunOS\ 5*) echo "Solaris";;
-     *)         echo "`uname -sr`";;
+     Linux\ 2.4.9*) echo "Linux.RH71";;
+     Linux\ 2.6.*)  echo "Linux.FC2";;
+     SunOS\ 5*)     echo "Solaris";;
+     Darwin*)       echo "Darwin";;
+     *)             echo "`uname -sr`";;
    esac
  }
 
@@ -185,16 +211,26 @@
  guess_gcc ()
  {
    case "$1" in
-     "Linux")   if which gcc3 > /dev/null 2>&1; then
-                  CXX=g++3
-                   CC=gcc3
-                fi
-                ;;
-     "Solaris") if [ -x /usr/local/gcc-3.0.4/bin/gcc ]; then
-                  CXX=/usr/local/gcc-3.0.4/bin/g++
-                   CC=/usr/local/gcc-3.0.4/bin/gcc
-                fi
-                ;;
+     "Linux.RH71") if which gcc > /dev/null 2>&1; then
+                     CXX=$LINUX_RH71_CXX
+                      CC=$LINUX_RH71_CC
+                   fi
+                   ;;
+     "Linux.FC2")  if which gcc > /dev/null 2>&1; then
+                     CXX=$LINUX_FC2_CXX
+                      CC=$LINUX_FC2_CC
+                   fi
+                   ;;
+     "Solaris")    if [ -x "$SOLARIS_CC" ]; then
+                     CXX=$SOLARIS_CXX
+                      CC=$SOLARIS_CC
+                   fi
+                   ;;
+     "Darwin")     if [ -x "$DARWIN_CC" ]; then
+                     CXX=$DARWIN_CXX
+                      CC=$DARWIN_CC
+                   fi
+                   ;;
    esac
  }
 
@@ -407,8 +443,10 @@
    echo "  o  Compilation environment."
 
    case "$ALLIANCE_OS" in
-     "Linux")   MAKE="make";;
-     "Solaris") MAKE="gmake";;
+     "Linux.RH71") MAKE="make";;
+     "Linux.FC2")  MAKE="make";;
+     "Solaris")    MAKE="gmake";;
+     "Darwin")     MAKE="make";;
      *) echo "attila: \"$ALLIANCE_OS\" is not supported, only Linux & Solaris"
         echo "        are."
 
@@ -416,7 +454,9 @@
    esac
    export MAKE
 
+   echo "     - TARGET      := `hostname`"
    echo "     - OS          := $ALLIANCE_OS"
+   echo "     - ID          := `id`"
    echo "     - MAKE        := $MAKE"
 
    guess_gcc $ALLIANCE_OS
@@ -468,10 +508,10 @@
      done
    fi
 
-   if [ ! -f Makefile.in -o ! -f configure ]; then
-     echo "  o  Running autostuff for Alliance top directory."
-     ./autostuff
-   fi
+  #if [ ! -f Makefile.in -o ! -f configure ]; then
+  #  echo "  o  Running autostuff for Alliance top directory."
+  #  ./autostuff
+  #fi
 
    if [ ! -d $BUILD_DIR ]; then
      echo "  o  Creating build directory $BUILD_DIR"
@@ -489,8 +529,16 @@
    for TOOL in $TOOLS; do
      cd  $HOME/alliance/src
      if [ ! -f "$TOOL/Makefile.in" -o ! -f "$TOOL/configure" ]; then
-       echo "     - Running autostuff for $TOOL."
-       ./autostuff $TOOL
+       echo "     - Running autostools for $TOOL."
+      #./autostuff $TOOL
+       cd $TOOL
+       aclocal -I . -I ..
+       if grep "^AM_PROG_LIBTOOL" configure.in >/dev/null; then
+          libtoolize --force --copy --automake
+       fi
+       automake --add-missing --copy --foreign
+       autoconf
+       cd ..
      fi
 
      cd $BUILD_DIR
@@ -501,6 +549,10 @@
      cd $TOOL
 
      echo "     - Running \"make $ARGS_MAKE\" for $TOOL."
+     if [ "$ASIM" = "y" ]; then
+       echo "     - Adding dynamic link support for ASIM install"
+       ARGS_CONFIGURE="$ARGS_CONFIGURE --enable-alc-shared"
+     fi
      $SRC_DIR/$TOOL/configure --prefix=$INSTALL_DIR $ARGS_CONFIGURE
      $MAKE prefix=$INSTALL_DIR $ARGS_MAKE
 
@@ -532,20 +584,28 @@
 
    CVS_STARTUP_FILES=""
 
- LINUX_TARGET="bip"
-     LINUX_CC="gcc3"
-    LINUX_CXX="g++3"
+ LINUX_RH71_TARGET="fa"
+     LINUX_RH71_CC="gcc3"
+    LINUX_RH71_CXX="g++3"
 
- SOLARIS_TARGET="beny"
-     SOLARIS_CC="/usr/local/gcc-3.0.4/bin/gcc3"
-    SOLARIS_CXX="/usr/local/gcc-3.0.4/bin/g++3"
+  LINUX_FC2_TARGET="tsunami"
+      LINUX_FC2_CC="gcc"
+     LINUX_FC2_CXX="g++"
+
+    SOLARIS_TARGET="funk"
+        SOLARIS_CC="/usr/local/bin/gcc"
+       SOLARIS_CXX="/usr/local/bin/g++"
+
+  DARWIN_TARGET="paques"
+      DARWIN_CC="gcc"
+     DARWIN_CXX="g++"
 
 
 # --------------------------------------------------------------------
 # Internal variables.
 
 
-             ALL_OSS="Linux Solaris"
+             ALL_OSS="Linux.RH71 Linux.FC2 Solaris"
                   CC=gcc
                  CXX=g++
               export CC CXX
@@ -566,6 +626,7 @@
                 ASIM="n"
                 FULL="n"
                 AUTO="n"
+               DEVEL="n"
                 SELF="$0"
         ATTILA_LOCAL="no"
 
@@ -600,6 +661,7 @@
        --ssh)         RSH="ssh";;
        --user)        ASIM="n";;
        --full)        FULL="y";;
+       --devel)       DEVEL="y";;
        --asim)        ASIM="y"; FULL="y";;
        --asim-noloop) ASIM="y";;
        --local)       ATTILA_LOCAL="y";;
@@ -637,6 +699,7 @@
                S) RSH="ssh";;
                U) ASIM="n";;
                F) FULL="y";;
+               d) DEVEL="y";;
                A) ASIM="y"; FULL="y";;
   
                *) echo "attila:error: Invalid option \`$CH'."
@@ -708,6 +771,7 @@
      ARGS="$ARGS --user"
    fi
    if [ "$ATTILA_LOCAL" = "y" ]; then ARGS="$ARGS --local"; fi
+   if [ "$DEVEL"        = "y" ]; then ARGS="$ARGS --devel"; fi
 
    for TOOL in $TOOLS; do
      ARGS="$ARGS --tool=$TOOL"
@@ -719,9 +783,13 @@
    ENVIRONMENT=""
    ENVIRONMENT="$ENVIRONMENT ALLIANCE_TOP=$ALLIANCE_TOP; export ALLIANCE_TOP;"
 
-   $RSH   $LINUX_TARGET "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
-   $RSH $SOLARIS_TARGET "/bin/bash -c \". /etc/profile; $ENVIRONMENT $SELF $ARGS\""
+   $RSH $LINUX_FC2_TARGET  "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
+   $RSH $LINUX_RH71_TARGET "/bin/bash -c \"$ENVIRONMENT $SELF $ARGS\""
+   $RSH $SOLARIS_TARGET    "/bin/bash -c \". /etc/profile; $ENVIRONMENT $SELF $ARGS\""
  else
   # Out of recursion...
+   if [ "$DEVEL" = "y" ]; then
+     ARGS_CONFIGURE="$ARGS_CONFIGURE --enable-devel"
+   fi
    compile_tool
  fi
