@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  *
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  *
  * This progam is  free software; you can redistribute it  and/or modify it
  * under the  terms of the GNU  General Public License as  published by the
@@ -31,7 +31,7 @@
 
 
 
-#ident "$Id: log_bdd1.c,v 1.1.1.1 2002/04/03 13:13:25 ludo Exp $"
+#ident "$Id: log_bdd1.c,v 1.2 2002/09/30 16:20:43 czo Exp $"
 
 
 /****************************************************************************/
