@@ -1,18 +1,46 @@
-#include "PPlacement.h"
+
+// This file is part of the Alliance Project.
+// Copyright (C) Laboratoire LIP6 - Departement ASIM
+// Universite Pierre et Marie Curie
+//
+// The Alliance Project  is free software;  you can  redistribute it and/or
+// modify  it  under the  terms  of  the  GNU  General  Public License  as
+// published by  the Free  Software Foundation; either  version 2  of  the
+// License, or (at your option) any later version.
+// 
+// The Alliance Project  is distributed in the hope that it will be useful,
+// but  WITHOUT  ANY  WARRANTY;  without  even  the  implied  warranty  of
+// MERCHANTABILITY  or  FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+// General Public License for more details.
+// 
+// You should have received a copy  of  the  GNU  General  Public  License
+// along with  the Alliance Project;  if  not,  write to the  Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+//
+// License-Tag
+//
+// Date   : 29/01/2004
+// Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
+//
+// Authors-Tag 
 #include <unistd.h>
 #include <set>
 #include <algorithm>
 #include <string>
+using namespace std;
+
 #include "mut.h"
 #include "mph.h"
 #include "mpu.h"
 #include "mlo.h"
 #include "mlu.h"
+
+#include "iocheader.h"
 #include "PMove.h"
 #include "PConstants.h"
 #include "PCommon.h"
-#include "iocheader.h"
-using namespace std;
+#include "PPlacement.h"
 
 struct CompPInsByWidth {
     bool operator()(PIns* Ins1, PIns* Ins2) {
@@ -142,7 +170,7 @@ PPlacement::Init(lofig* fig, int NbRows)
     _nInsToPlace = _toPlaceInss.size();
 
     // Traitement des connecteurs ....
-    if (_placeCons || _ringPlaceCons)
+    if (_placeCons || (_ringPlaceCons && !_iocFile))
     {
 	for (locon* con = fig->LOCON; con; con = con->NEXT)
 	{
@@ -383,7 +411,7 @@ PPlacement::Init(lofig* fig, int NbRows)
     // set positions of connectors in case of no ioc file
     if (_placeCons && !_ringPlaceCons) GenerateConsPlacement();
     
-    if (_ringPlaceCons) GenerateRingConsPlacement();
+    if (_ringPlaceCons && !_iocFile) GenerateRingConsPlacement();
     
     // set positions of connectors when ioc file is given
     if (_iocFile) SetPosIocFile(pconmap);
@@ -649,7 +677,7 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
 
   if (leftcount != 0)
   {
-    double pos = 0.0;
+    double pos = 0.0, ppos = pos;
     if (leftspace >= Width-topcount)
     {
       cerr << " o ERROR : in ioc file : space too important" << endl;
@@ -657,6 +685,7 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
     }
     double conspace = ((double)(Height-leftspace)/
 					(double)(leftcount-nbspaceleft));
+    if (_ringPlaceCons) ppos = pos;
     pos += conspace / 2.0;
 
     for(con_list* tmpcon = ptleft ; tmpcon; tmpcon = tmpcon->NEXT)
@@ -668,12 +697,23 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
       }
       else
       {
+        if (_ringPlaceCons)
+        {
+	int delta = (int)pos % ROWHEIGHT;
+          if      (delta == 0) pos -=  2.0;
+          else if (delta == 1) pos +=  1.0;
+          else if (delta == 9) pos -=  1.0;
+          // Just in case there are so many connectors
+          if (pos < ppos) pos = ppos + 1;
+        }
+
 	if (_verbose) cout << " o adding connector : " << tmpcon->NAME
 	  << " x : " << 0 << " y : " << (int)pos << endl;
 	position.SetX(0.0);
 	position.SetY((double)(int)pos);
 	// test a rajouter pour verifier si locon present ou pas!!!
 	pconmap[tmpcon->NAME]->SetPos(position);
+        if (_ringPlaceCons) ppos = pos;
 	pos += conspace;
       }
     }
@@ -681,7 +721,7 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
 
   if (rightcount != 0)
   {
-    double pos = 0.0;
+    double pos = 0.0, ppos = pos;
     if (rightspace >= Width-topcount)
     {
       cerr << " o ERROR : in ioc file : space too important" << endl;
@@ -689,6 +729,7 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
     }
     double conspace = ((double)(Height-rightspace)/
 					(double)(rightcount-nbspaceright));
+    if (_ringPlaceCons) ppos = pos;
     pos += conspace / 2.0;
 
     for(con_list* tmpcon = ptright ; tmpcon; tmpcon = tmpcon->NEXT)
@@ -700,12 +741,23 @@ PPlacement::SetPosIocFile(PConMap& pconmap)
       }
       else
       {
+        if (_ringPlaceCons)
+        {
+	int delta = (int)pos % ROWHEIGHT;
+         if      (delta == 0) pos -=  2.0;
+         else if (delta == 1) pos +=  1.0;
+         else if (delta == 9) pos -=  1.0;
+	 // Just in case there are so many connectors
+	 if (pos < ppos) pos = ppos + 1;
+        }
+
 	if (_verbose) cout << " o adding connector: " << tmpcon->NAME
 	  << " x : " << Width << " y : " << (int)pos << endl;
 	position.SetX(Width);
 	position.SetY((double)(int)pos);
 	// test a rajouter pour verifier si locon present ou pas!!!
 	pconmap[tmpcon->NAME]->SetPos(position);
+        if (_ringPlaceCons) ppos = pos;
 	pos += conspace;
       }
     }
@@ -1297,7 +1349,12 @@ void
 PPlacement::InitPlaceWithPrePlace()
 {
     // abutment box
-    assert(_prePlaceFig);
+    if (!_prePlaceFig)
+    {
+        cerr << " o ERROR: impossible to init preplacement with empty preplacement figure" << endl;
+        exit(1);
+    }
+
     int Width = _prePlaceFig->XAB2 - _prePlaceFig->XAB1;
     int Height = _prePlaceFig->YAB2 - _prePlaceFig->YAB1;
 
@@ -1495,7 +1552,11 @@ PPlacement::CreateSubRows(PRow* row, PrePlaceTab& tabpreplace,
 	row->_subRowsXMaxInv[srymit->first] = srymit->second;
     }
   }
-  assert(subrowscreated == nbsubrows);
+  if (subrowscreated != nbsubrows)
+  {
+      cerr << " o INTERNAL ERROR : in subrow creation" << endl;
+      exit (1);
+  }
 }
 
 // ======================================================================
