@@ -1,21 +1,60 @@
+
+// This file is part of the Alliance Project.
+// Copyright (C) Laboratoire LIP6 - Departement ASIM
+// Universite Pierre et Marie Curie
+//
+// The Alliance Project  is free software;  you can  redistribute it and/or
+// modify  it  under the  terms  of  the  GNU  General  Public License  as
+// published by  the Free  Software Foundation; either  version 2  of  the
+// License, or (at your option) any later version.
+// 
+// The Alliance Project  is distributed in the hope that it will be useful,
+// but  WITHOUT  ANY  WARRANTY;  without  even  the  implied  warranty  of
+// MERCHANTABILITY  or  FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+// General Public License for more details.
+// 
+// You should have received a copy  of  the  GNU  General  Public  License
+// along with  the Alliance Project;  if  not,  write to the  Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+//
+// License-Tag
+//
+// Date   : 29/01/2004
+// Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
+//
+// Authors-Tag 
 #ifndef __PPLACEMENT_H
 #define __PPLACEMENT_H
 
+#ifdef __GNUC__
+#if __GNUC__ < 3
+#include <hash_map.h>
+#else
+#include <ext/hash_map>
+#if __GNUC_MINOR__ == 0
+#else
+using namespace __gnu_cxx; // GCC 3.1 and later
+#endif
+#endif
+#endif
+
 #include <iostream>
 #include <fstream>
 #include <vector>
 #include <map>
-#include <hash_map.h>
+using namespace std;
+
+#include "mut.h"
+#include "mlo.h"
+
 #include "PToPlaceIns.h"
 #include "PFixedIns.h"
 #include "PCon.h"
 #include "PONet.h"
 #include "PBBox.h"
 #include "PDetSubRow.h"
-#include "mut.h"
-#include "mlo.h"
 #include "iocheader.h"
-using namespace std;
 
 struct eqstr
 {
