@@ -1,11 +1,39 @@
-#include "PPlacement.h"
+
+// This file is part of the Alliance Project.
+// Copyright (C) Laboratoire LIP6 - Departement ASIM
+// Universite Pierre et Marie Curie
+//
+// The Alliance Project  is free software;  you can  redistribute it and/or
+// modify  it  under the  terms  of  the  GNU  General  Public License  as
+// published by  the Free  Software Foundation; either  version 2  of  the
+// License, or (at your option) any later version.
+// 
+// The Alliance Project  is distributed in the hope that it will be useful,
+// but  WITHOUT  ANY  WARRANTY;  without  even  the  implied  warranty  of
+// MERCHANTABILITY  or  FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+// General Public License for more details.
+// 
+// You should have received a copy  of  the  GNU  General  Public  License
+// along with  the Alliance Project;  if  not,  write to the  Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+//
+// License-Tag
+//
+// Date   : 29/01/2004
+// Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
+//
+// Authors-Tag 
 #include <stdio.h>
 #include <math.h>
 #include <unistd.h>
-#include "PMove.h"
+using namespace std;
 
+#include "PMove.h"
 #include "PConstants.h"
 
+#include "PPlacement.h"
+
 static double
 DoubleRand(void)
 {
@@ -360,6 +388,9 @@ PPlacement::PlaceGlobal()
 
     } while (Temperature != 0.0 && StdDev > 0.0001 / Cost);
 
+    if (!_boolPlot)
+       unlink("alldata.dat");
+
     if (!stucked)
     {
 	// Freeze out
