@@ -1,8 +1,35 @@
-#include "PRow.h"
+
+// This file is part of the Alliance Project.
+// Copyright (C) Laboratoire LIP6 - Departement ASIM
+// Universite Pierre et Marie Curie
+//
+// The Alliance Project  is free software;  you can  redistribute it and/or
+// modify  it  under the  terms  of  the  GNU  General  Public License  as
+// published by  the Free  Software Foundation; either  version 2  of  the
+// License, or (at your option) any later version.
+// 
+// The Alliance Project  is distributed in the hope that it will be useful,
+// but  WITHOUT  ANY  WARRANTY;  without  even  the  implied  warranty  of
+// MERCHANTABILITY  or  FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+// General Public License for more details.
+// 
+// You should have received a copy  of  the  GNU  General  Public  License
+// along with  the Alliance Project;  if  not,  write to the  Free Software
+// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//
+//
+// License-Tag
+//
+// Date   : 29/01/2004
+// Author : Christophe Alexandre  <Christophe.Alexandre@lip6.fr>
+//
+// Authors-Tag 
 #include "PPlacement.h"
 #include "PConstants.h"
 #include "PBBox.h"
 
+#include "PRow.h"
+
 PRow::PRow(unsigned nbofsubrows)
     : PContainer(), _subRows(nbofsubrows)
 {
@@ -88,7 +115,11 @@ PRow::GetSubRow(const double X)
 
     if (right == _subRowsXMax.end())
     {
-	assert(left != _subRowsXMaxInv.end());
+        if (left == _subRowsXMaxInv.end())
+        {
+            cerr << " o INTERNAL ERROR: GetSubRow()" << endl;
+            exit(1);
+        }
 	return *_subRows[left->second];
     }
 
@@ -101,7 +132,11 @@ PRow::GetSubRow(const double X)
     // si il n'y a rien a gauche...
     if (left == _subRowsXMaxInv.end())
     {
-	assert(right != _subRowsXMax.end());
+	if (right == _subRowsXMax.end())
+        {
+            cerr << " o INTERNAL ERROR: GetSubRow()" << endl;
+            exit(1);
+        }
 	return *_subRows[right->second];
     }
 
