@@ -4,7 +4,7 @@
  * Universite Pierre et Marie Curie
  *
  * Home page          : http://www-asim.lip6.fr/alliance/
- * E-mail support     : mailto:alliance-support@asim.lip6.fr
+ * E-mail             : mailto:alliance-users@asim.lip6.fr
  *
  * This progam is  free software; you can redistribute it  and/or modify it
  * under the  terms of the GNU  General Public License as  published by the
@@ -1132,7 +1132,7 @@ void post_treat (model, scotch_on_flag, verbose, autoimp)
 
       if (!modelp->FLAGS && !incataloggds (modelp->NAME))
       {
-         post_treat (modelp, scotch_on_flag, verbose);
+         post_treat (modelp, scotch_on_flag, verbose, autoimp);
       }
    }
    if (verbose)
