@@ -97,7 +97,9 @@
      <EnterWindow>:   CallbackEvent( 3 )\n\
      <LeaveWindow>:   CallbackEvent( 4 )\n\
      <Key>osfUp:      CallbackEvent( 5 )\n\
+     <Btn4Down>:      CallbackEvent( 5 )\n\
      <Key>osfDown:    CallbackEvent( 6 )\n\
+     <Btn5Down>:      CallbackEvent( 6 )\n\
      <Key>osfLeft:    CallbackEvent( 7 )\n\
      <Key>osfRight:   CallbackEvent( 8 )\n\
      <Key>Z:          CallbackEvent( 9 )\n\
@@ -739,7 +741,7 @@ void CallbackExpose( MyWidget, ClientData, CallData )
       XvpnDisplayCursor();
     }
 
-    XvpnEnterPresentPanel();
+    /* XvpnEnterPresentPanel(); */
   }
   else
   {
